@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+import datetime
 import sys
 from typing import TYPE_CHECKING
 
@@ -10,7 +13,7 @@ if TYPE_CHECKING:
 
 
 def transfer_task_wait_with_io(
-    transfer_client: "CustomTransferClient",
+    transfer_client: CustomTransferClient,
     meow,
     heartbeat,
     polling_interval,
@@ -99,3 +102,15 @@ def transfer_task_wait_with_io(
     formatted_print(res, text_format=FORMAT_SILENT)
 
     click.get_current_context().exit(exit_code)
+
+
+def isoformat_to_local(
+    utc_str: str | None, localtz: datetime.tzinfo | None = None
+) -> str | None:
+    if not utc_str:
+        return None
+    # let this raise ValueError
+    date = datetime.datetime.fromisoformat(utc_str)
+    if date.tzinfo is None:
+        return date.strftime("%Y-%m-%d %H:%M:%S")
+    return date.astimezone(tz=localtz).strftime("%Y-%m-%d %H:%M:%S")
