@@ -18,6 +18,7 @@ from .output_formatter import (
     FORMAT_SILENT,
     FORMAT_TEXT_RAW,
     FORMAT_TEXT_RECORD,
+    FORMAT_TEXT_RECORD_LIST,
     FORMAT_TEXT_TABLE,
     FormatField,
     formatted_print,
@@ -43,6 +44,7 @@ __all__ = [
     "FORMAT_JSON",
     "FORMAT_TEXT_TABLE",
     "FORMAT_TEXT_RECORD",
+    "FORMAT_TEXT_RECORD_LIST",
     "FORMAT_TEXT_RAW",
     "out_is_terminal",
     "env_interactive",
